Class: TreezorClient::TransferrefundApi

Inherits:
Object
  • Object
show all
Defined in:
lib/treezor_client/api/transferrefund_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ TransferrefundApi



19
20
21
# File 'lib/treezor_client/api/transferrefund_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/treezor_client/api/transferrefund_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#delete_transferrefund(id, opts = {}) ⇒ InlineResponse20024

cancel a transfer refund Change transfer refund's status to CANCELED. A validated transfer refund can't be cancelled.



27
28
29
30
# File 'lib/treezor_client/api/transferrefund_api.rb', line 27

def delete_transferrefund(id, opts = {})
  data, _status_code, _headers = delete_transferrefund_with_http_info(id, opts)
  data
end

#delete_transferrefund_with_http_info(id, opts = {}) ⇒ Array<(InlineResponse20024, Fixnum, Hash)>

cancel a transfer refund Change transfer refund's status to CANCELED. A validated transfer refund can't be cancelled.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/treezor_client/api/transferrefund_api.rb', line 37

def delete_transferrefund_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TransferrefundApi.delete_transferrefund ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling TransferrefundApi.delete_transferrefund"
  end
  # resource path
  local_var_path = '/transferrefunds/{id}'.sub('{' + 'id' + '}', id.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = ['api_key']
  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'InlineResponse20024')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransferrefundApi#delete_transferrefund\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_transferrefund(id, opts = {}) ⇒ InlineResponse20024

get a transfer refund Get a transfer refund from the system.



81
82
83
84
# File 'lib/treezor_client/api/transferrefund_api.rb', line 81

def get_transferrefund(id, opts = {})
  data, _status_code, _headers = get_transferrefund_with_http_info(id, opts)
  data
end

#get_transferrefund_with_http_info(id, opts = {}) ⇒ Array<(InlineResponse20024, Fixnum, Hash)>

get a transfer refund Get a transfer refund from the system.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/treezor_client/api/transferrefund_api.rb', line 91

def get_transferrefund_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TransferrefundApi.get_transferrefund ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling TransferrefundApi.get_transferrefund"
  end
  # resource path
  local_var_path = '/transferrefunds/{id}'.sub('{' + 'id' + '}', id.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = ['api_key']
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'InlineResponse20024')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransferrefundApi#get_transferrefund\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_transferrefunds(opts = {}) ⇒ InlineResponse20024

search transfer refunds Get transfer refunds that match search criteria.

Options Hash (opts):

  • :access_signature (String)

    Access signature can be mandatory for specific context. Treezor will contact you if so. More info here.

  • :access_tag (String)

    Access tag is used for idem potency query. More info here.

  • :access_user_id (Integer)

    Access user's id is used for user's action restriction. More info here.

  • :access_user_ip (String)

    Access user's ip is used for user's action restriction. More info here.

  • :transferrefund_id (Integer)

    Transfer refund id.

  • :transferrefund_tag (String)

    Custom data.

  • :transferrefund_status (String)

    Transfer refund status. Possible values: * PENDING * CANCELED * VALIDATED

  • :wallet_id (Integer)

    Refunded wallet's id.

  • :transfer_id (Integer)

    Initial transfer's id.

  • :transferrefund_date (Integer)

    transfert refund's date. Format: YYYY-MM-DD HH:MM:SS

  • :user_id (Integer)

    User's id of who has made the transfer refund.

  • :amount (String)

    Refund amount.

  • :currency (String)

    Transfert amount currency. Format: ISO 4217.

  • :page_number (Integer)

    Pagination page number. More info here.

  • :page_count (Integer)

    The number of items per page. More info here.

  • :sort_by (String)

    The transaction element you want to sort the list with. Default value : createdDate. More info here.

  • :sort_order (String)

    The order you want to sort the list. * DESC for a descending sort * ASC for a ascending sort. Default value : DESC. More info here.

  • :created_date_from (DateTime)

    The creation date from which you want to filter the request result. Format YYYY-MM-DD HH:MM:SS. More info here

  • :created_date_to (DateTime)

    The creation date up to which you want to filter the request result. Format YYYY-MM-DD HH:MM:SS. More info here

  • :updated_date_from (DateTime)

    The modification date from which you want to filter the request result. Format YYYY-MM-DD HH:MM:SS. More info here

  • :updated_date_to (DateTime)

    The modification date up to which you want to filter the request result. Format YYYY-MM-DD HH:MM:SS. More info here



155
156
157
158
# File 'lib/treezor_client/api/transferrefund_api.rb', line 155

def get_transferrefunds(opts = {})
  data, _status_code, _headers = get_transferrefunds_with_http_info(opts)
  data
end

#get_transferrefunds_with_http_info(opts = {}) ⇒ Array<(InlineResponse20024, Fixnum, Hash)>

search transfer refunds Get transfer refunds that match search criteria.

Options Hash (opts):

  • :access_signature (String)

    Access signature can be mandatory for specific context. Treezor will contact you if so. More info here.

  • :access_tag (String)

    Access tag is used for idem potency query. More info here.

  • :access_user_id (Integer)

    Access user's id is used for user's action restriction. More info here.

  • :access_user_ip (String)

    Access user's ip is used for user's action restriction. More info here.

  • :transferrefund_id (Integer)

    Transfer refund id.

  • :transferrefund_tag (String)

    Custom data.

  • :transferrefund_status (String)

    Transfer refund status. Possible values: * PENDING * CANCELED * VALIDATED

  • :wallet_id (Integer)

    Refunded wallet's id.

  • :transfer_id (Integer)

    Initial transfer's id.

  • :transferrefund_date (Integer)

    transfert refund's date. Format: YYYY-MM-DD HH:MM:SS

  • :user_id (Integer)

    User's id of who has made the transfer refund.

  • :amount (String)

    Refund amount.

  • :currency (String)

    Transfert amount currency. Format: ISO 4217.

  • :page_number (Integer)

    Pagination page number. More info here.

  • :page_count (Integer)

    The number of items per page. More info here.

  • :sort_by (String)

    The transaction element you want to sort the list with. Default value : createdDate. More info here.

  • :sort_order (String)

    The order you want to sort the list. * DESC for a descending sort * ASC for a ascending sort. Default value : DESC. More info here.

  • :created_date_from (DateTime)

    The creation date from which you want to filter the request result. Format YYYY-MM-DD HH:MM:SS. More info here

  • :created_date_to (DateTime)

    The creation date up to which you want to filter the request result. Format YYYY-MM-DD HH:MM:SS. More info here

  • :updated_date_from (DateTime)

    The modification date from which you want to filter the request result. Format YYYY-MM-DD HH:MM:SS. More info here

  • :updated_date_to (DateTime)

    The modification date up to which you want to filter the request result. Format YYYY-MM-DD HH:MM:SS. More info here



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/treezor_client/api/transferrefund_api.rb', line 185

def get_transferrefunds_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TransferrefundApi.get_transferrefunds ...'
  end
  # resource path
  local_var_path = '/transferrefunds'

  # query parameters
  query_params = {}
  query_params[:'accessSignature'] = opts[:'access_signature'] if !opts[:'access_signature'].nil?
  query_params[:'accessTag'] = opts[:'access_tag'] if !opts[:'access_tag'].nil?
  query_params[:'accessUserId'] = opts[:'access_user_id'] if !opts[:'access_user_id'].nil?
  query_params[:'accessUserIp'] = opts[:'access_user_ip'] if !opts[:'access_user_ip'].nil?
  query_params[:'transferrefundId'] = opts[:'transferrefund_id'] if !opts[:'transferrefund_id'].nil?
  query_params[:'transferrefundTag'] = opts[:'transferrefund_tag'] if !opts[:'transferrefund_tag'].nil?
  query_params[:'transferrefundStatus'] = opts[:'transferrefund_status'] if !opts[:'transferrefund_status'].nil?
  query_params[:'walletId'] = opts[:'wallet_id'] if !opts[:'wallet_id'].nil?
  query_params[:'transferId'] = opts[:'transfer_id'] if !opts[:'transfer_id'].nil?
  query_params[:'transferrefundDate'] = opts[:'transferrefund_date'] if !opts[:'transferrefund_date'].nil?
  query_params[:'userId'] = opts[:'user_id'] if !opts[:'user_id'].nil?
  query_params[:'amount'] = opts[:'amount'] if !opts[:'amount'].nil?
  query_params[:'currency'] = opts[:'currency'] if !opts[:'currency'].nil?
  query_params[:'pageNumber'] = opts[:'page_number'] if !opts[:'page_number'].nil?
  query_params[:'pageCount'] = opts[:'page_count'] if !opts[:'page_count'].nil?
  query_params[:'sortBy'] = opts[:'sort_by'] if !opts[:'sort_by'].nil?
  query_params[:'sortOrder'] = opts[:'sort_order'] if !opts[:'sort_order'].nil?
  query_params[:'createdDateFrom'] = opts[:'created_date_from'] if !opts[:'created_date_from'].nil?
  query_params[:'createdDateTo'] = opts[:'created_date_to'] if !opts[:'created_date_to'].nil?
  query_params[:'updatedDateFrom'] = opts[:'updated_date_from'] if !opts[:'updated_date_from'].nil?
  query_params[:'updatedDateTo'] = opts[:'updated_date_to'] if !opts[:'updated_date_to'].nil?

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = ['api_key']
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'InlineResponse20024')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransferrefundApi#get_transferrefunds\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_transferrefunds(transfer_id, amount, currency, opts = {}) ⇒ InlineResponse20025

create a transfer refund Create a new transfer refund in the system.

Options Hash (opts):

  • :access_signature (String)

    Access signature can be mandatory for specific context. Treezor will contact you if so. More info here.

  • :access_tag (String)

    Access tag is used for idem potency query. More info here.

  • :access_user_id (Integer)

    Access user's id is used for user's action restriction. More info here.

  • :access_user_ip (String)

    Access user's ip is used for user's action restriction. More info here.

  • :transferrefund_tag (String)

    Custom data.

  • :comment (String)

    End user, client or issuer comment.



254
255
256
257
# File 'lib/treezor_client/api/transferrefund_api.rb', line 254

def post_transferrefunds(transfer_id, amount, currency, opts = {})
  data, _status_code, _headers = post_transferrefunds_with_http_info(transfer_id, amount, currency, opts)
  data
end

#post_transferrefunds_with_http_info(transfer_id, amount, currency, opts = {}) ⇒ Array<(InlineResponse20025, Fixnum, Hash)>

create a transfer refund Create a new transfer refund in the system.

Options Hash (opts):

  • :access_signature (String)

    Access signature can be mandatory for specific context. Treezor will contact you if so. More info here.

  • :access_tag (String)

    Access tag is used for idem potency query. More info here.

  • :access_user_id (Integer)

    Access user's id is used for user's action restriction. More info here.

  • :access_user_ip (String)

    Access user's ip is used for user's action restriction. More info here.

  • :transferrefund_tag (String)

    Custom data.

  • :comment (String)

    End user, client or issuer comment.



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/treezor_client/api/transferrefund_api.rb', line 272

def post_transferrefunds_with_http_info(transfer_id, amount, currency, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TransferrefundApi.post_transferrefunds ...'
  end
  # verify the required parameter 'transfer_id' is set
  if @api_client.config.client_side_validation && transfer_id.nil?
    fail ArgumentError, "Missing the required parameter 'transfer_id' when calling TransferrefundApi.post_transferrefunds"
  end
  # verify the required parameter 'amount' is set
  if @api_client.config.client_side_validation && amount.nil?
    fail ArgumentError, "Missing the required parameter 'amount' when calling TransferrefundApi.post_transferrefunds"
  end
  # verify the required parameter 'currency' is set
  if @api_client.config.client_side_validation && currency.nil?
    fail ArgumentError, "Missing the required parameter 'currency' when calling TransferrefundApi.post_transferrefunds"
  end
  # resource path
  local_var_path = '/transferrefunds'

  # query parameters
  query_params = {}
  query_params[:'transferId'] = transfer_id
  query_params[:'amount'] = amount
  query_params[:'currency'] = currency
  query_params[:'accessSignature'] = opts[:'access_signature'] if !opts[:'access_signature'].nil?
  query_params[:'accessTag'] = opts[:'access_tag'] if !opts[:'access_tag'].nil?
  query_params[:'accessUserId'] = opts[:'access_user_id'] if !opts[:'access_user_id'].nil?
  query_params[:'accessUserIp'] = opts[:'access_user_ip'] if !opts[:'access_user_ip'].nil?
  query_params[:'transferrefundTag'] = opts[:'transferrefund_tag'] if !opts[:'transferrefund_tag'].nil?
  query_params[:'comment'] = opts[:'comment'] if !opts[:'comment'].nil?

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = ['api_key']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'InlineResponse20025')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransferrefundApi#post_transferrefunds\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end